summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/bbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/torrent/bbase.h')
-rw-r--r--kfile-plugins/torrent/bbase.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kfile-plugins/torrent/bbase.h b/kfile-plugins/torrent/bbase.h
index 046bd545..36eccd39 100644
--- a/kfile-plugins/torrent/bbase.h
+++ b/kfile-plugins/torrent/bbase.h
@@ -79,11 +79,11 @@ class BBase : public KShared
/**
* Outputs the b-encoded representation of the object to the given
* QIODevice.
* @param device the QIODevice to write to
* @return true on a successful write, false otherwise
*/
- virtual bool writeToDevice (QIODevice &device) = 0;
+ virtual bool writeToDevice (TQIODevice &device) = 0;
};
#endif /* _BBASE_H */
@@ -79,11 +79,11 @@ class BBase : public KShared
/**
* Outputs the b-encoded representation of the object to the given
- * QIODevice.
- * @param device the QIODevice to write to
+ * TQIODevice.
+ * @param device the TQIODevice to write to
* @return true on a successful write, false otherwise
*/